@@ -126,53 +126,23 @@ void
 gpm_help_display (const gchar *link_id)
 {
 	GError *error = NULL;
-	char *command;
-	const char *lang;
-	char *uri = NULL;
-	GdkScreen *gscreen;
+	gchar *uri;
 
-	int i;
+	if (link_id)
+		uri = g_strconcat ("ghelp:cheese?", link_id, NULL);
+	else
+		uri = g_strdup ("ghelp:cheese");
 
-	const char * const * langs = g_get_language_names ();
+	gtk_show_uri (NULL, uri, GDK_CURRENT_TIME, &error);
 
-	for (i = 0; langs[i]; i++) {
-		lang = langs[i];
-		if (strchr (lang, '.')) {
-			continue;
-		}
-
-		uri = g_build_filename(DATADIR,
-				       "/gnome/help/gnome-power-manager/",
-					lang,
-				       "/gnome-power-manager.xml",
-					NULL);
-					
-		if (g_file_test (uri, G_FILE_TEST_EXISTS)) {
-                    break;
-		}
-	}
-	
-	if (link_id) {
-		command = g_strconcat ("gnome-open ghelp://", uri, "?", link_id, NULL);
-	} else {
-		command = g_strconcat ("gnome-open ghelp://", uri,  NULL);
-	}
-
-	gscreen = gdk_screen_get_default();
-	gdk_spawn_command_line_on_screen (gscreen, command, &error);
 	if (error != NULL) {
 		GtkWidget *d;
-
-		d = gtk_message_dialog_new(NULL,
-				GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-				GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-				"%s", error->message);
-		gtk_dialog_run(GTK_DIALOG(d));
-		gtk_widget_destroy(d);
-		g_error_free(error);
+		d = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+					    GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", error->message);
+		gtk_dialog_run (GTK_DIALOG(d));
+		gtk_widget_destroy (d);
+		g_error_free (error);
 	}
-
-	g_free (command);
 	g_free (uri);
 }
 
